==> nextcloud-22.2.10.tgz: nextcloud/apps/comments/l10n/mk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Kоментиравте",
    "%1$s commented" : "%1$s коментиран",
    "{author} commented" : "{author} коментираше",
    "You commented on %1$s" : "Коментиравте на %1$s",
    "You commented on {file}" : "Коментиравте на {file}",
    "%1$s commented on %2$s" : "%1$s коментираше на %2$s",
    "{author} commented on {file}" : "{author} коментираше на {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за датотеки",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Бевте спомнати на коментар на “{file}”, од корисник кој сега е избришан",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} те спомна во коментар на датотеката “{file}”",
    "Files app plugin to add comments to files" : "Додади додаток за коментирање на датотеки",
    "Edit comment" : "Измени го коментарот",
    "Delete comment" : "Избриши коментар",
    "Cancel edit" : "Откажи ажурирање",
    "Post comment" : "Објави коментар",
    "No comments yet, start the conversation!" : "Сеуште нема коментари, започнете разговор!",
    "No more messages" : "Нема повеќе пораки",
    "Retry" : "Обидете се повторно",
    "Unable to load the comments list" : "Неможе да се вчита листата на коментари",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитан коментар","%n непрочитани коментари"],
    "_1 new comment_::_{unread} new comments_" : ["1 нов коментар","{unread} нови коментари"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Настана грешка при обид за ажурирање на коментар",
    "Comment deleted" : "Коментарот е избришан",
    "An error occurred while trying to delete the comment" : "Настана грешка при обидот за бришење на коментар",
    "An error occurred while trying to create the comment" : "Настана грешка при обидот за креирање на коментар",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Бевте спомнати на коментар на “{file}”, од корисник кој сега е избришан",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомна во коментар на датотеката “{file}”"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/comments/l10n/mk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Kоментиравте",
    "{author} commented" : "{author} коментираше",
    "You commented on %1$s" : "Коментиравте на %1$s",
    "You commented on {file}" : "Коментиравте на {file}",
    "%1$s commented on %2$s" : "%1$s коментираше на %2$s",
    "{author} commented on {file}" : "{author} коментираше на {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за датотеки",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Бевте спомнати на коментар на “{file}”, од корисник кој сега е избришан",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} те спомна во коментар на датотеката “{file}”",
    "Files app plugin to add comments to files" : "Додади додаток за коментирање на датотеки",
    "Edit comment" : "Измени го коментарот",
    "Delete comment" : "Избриши коментар",
    "Cancel edit" : "Откажи ажурирање",
    "Post comment" : "Објави коментар",
    "No comments yet, start the conversation!" : "Сеуште нема коментари, започнете разговор!",
    "No more messages" : "Нема повеќе пораки",
    "Retry" : "Обидете се повторно",
    "Failed to mark comments as read" : "Неуспешно означување на коментарот како прочитан",
    "Unable to load the comments list" : "Неможе да се вчита листата на коментари",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитан коментар","%n непрочитани коментари"],
    "_1 new comment_::_{unread} new comments_" : ["1 нов коментар","{unread} нови коментари"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Настана грешка при обид за ажурирање на коментар",
    "Comment deleted" : "Коментарот е избришан",
    "An error occurred while trying to delete the comment" : "Настана грешка при обидот за бришење на коментар",
    "An error occurred while trying to create the comment" : "Настана грешка при обидот за креирање на коментар",
    "%1$s commented" : "%1$s коментиран"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
